@@ -127,6 +127,17 @@ namespace pcl
         /** \brief Destructor. */
         virtual ~ImageViewer ();
        
+#if ((VTK_MAJOR_VERSION > 5) || ((VTK_MAJOR_VERSION == 5) && (VTK_MINOR_VERSION > 4)))
+        /** \brief Set up the interactor style. By default the interactor style is set to
+          * vtkInteractorStyleImage you can use this to set it to another type.
+          * \param[in] style user set interactor style.
+          */
+        void
+        setInteractorStyle (vtkInteractorObserver *style)
+        {
+          interactor_->SetInteractorStyle (style);
+        }
+#endif
         /** \brief Show a monochrome 2D image on screen.
           * \param[in] data the input data representing the image
           * \param[in] width the width of the image
@@ -721,6 +732,31 @@ namespace pcl
         addLine (unsigned int x_min, unsigned int y_min, unsigned int x_max, unsigned int y_max,
                  const std::string &layer_id = "line", double opacity = 1.0);
 
+        /** \brief Add a 2D text with a given color
+          * \param[in] x the X coordinate
+          * \param[in] y the Y coordinate
+          * \param[in] text the text string to be displayed
+          * \param[in] r the red channel of the color that the line should be rendered with (0.0 -> 1.0)
+          * \param[in] g the green channel of the color that the line should be rendered with (0.0 -> 1.0)
+          * \param[in] b the blue channel of the color that the line should be rendered with (0.0 -> 1.0)
+          * \param[in] layer_id the 2D layer ID where we want the extra information to be drawn.
+          * \param[in] opacity the opacity of the layer: 0 for invisible, 1 for opaque. (default: 1.0)
+          */
+        bool
+        addText (unsigned int x, unsigned int y, const std::string& text,
+                 double r, double g, double b,
+                 const std::string &layer_id = "line", double opacity = 1.0);
+
+        /** \brief Add a 2D text with a given color
+          * \param[in] x the X coordinate
+          * \param[in] y the Y coordinate
+          * \param[in] text the text string to be displayed
+          * \param[in] layer_id the 2D layer ID where we want the extra information to be drawn.
+          * \param[in] opacity the opacity of the layer: 0 for invisible, 1 for opaque. (default: 1.0)
+          */
+        bool
+        addText (unsigned int x, unsigned int y, const std::string& text,
+                 const std::string &layer_id = "line", double opacity = 1.0);
 
         /** \brief Add a generic 2D mask to an image 
           * \param[in] image the organized point cloud dataset containing the image data
